Calculates different values of shattering coefficient and delta, varying # of samples to study the chernoff bound of SLT.
chernoff_bound(rpart.tree, n_experimentations, epsilon)rpart.tree. A Decision tree generated by rpart package.
int. The # of experimentations and samples to run.
float. The epsilon to be used in the delta calculation.
No return value, the function plots the chernoff bound.