Learn R Programming

shatteringdt (version 0.1.0)

search_delta_n_samples: Search the # of samples to ensure learning given an epsilon.

Description

Search the # of samples to ensure learning given an epsilon.

Usage

search_delta_n_samples(rpart.tree, n_samples, delta, epsilon)

Arguments

rpart.tree

rpart.tree. A Decision tree generated by rpart package.

n_samples

int. The # of samples to be used as initial value to search the minimum necessary to ensure learning.

delta

float. The initial value of delta (need to be greater than epsilon)

epsilon

float. The epsilon to be used in the delta calculation.

Value

the delta and n_samples values.