Learn R Programming

shatteringdt (version 0.1.0)

search_n_samples: Executes a binary search to find the best # of samples.

Description

Executes a binary search to find the best # of samples.

Usage

search_n_samples(rpart.tree, lower, upper, epsilon)

Arguments

rpart.tree

rpart.tree. A Decision tree generated by rpart package.

lower

int. The # of samples to be used in lower_delta calculation.

upper

int. The # of samples to be used in upper_delta calculation.

epsilon

float. The epsilon to be used in the delta calculation.

Value

the number of samples needed to ensure learning.