Using a recursion, calculates the shattering coefficient for a rpart decision tree.
recurse(nodes, left, right, node, parent, samples, node_type, shattering, n_samples)list. A list containing the tree nodes.
int. The left child of the parent node.
int. The right child of the parent node.
int. The current node being analyzed
int. The parent node of node.
list. The number of dataset samples for each node of the tree.
string. The type of the node, e.g., leaf if it's a leaf node.
float. The shattering coefficient that are begin computed.
int. The # of samples to consider in dataset.
The calculus of the shattering coefficient.