Executes a binary search to find the best # of samples.
search_n_samples(rpart.tree, lower, upper, epsilon)rpart.tree. A Decision tree generated by rpart package.
int. The # of samples to be used in lower_delta calculation.
int. The # of samples to be used in upper_delta calculation.
float. The epsilon to be used in the delta calculation.
the number of samples needed to ensure learning.